==> apache-stanbol-0.12.0-source-release.zip: apache-stanbol-0.12.0/enhancement-engines/opennlp/opennlp-ner/src/main/java/org/apache/stanbol/enhancer/engines/opennlp/impl/NameOccurrence.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.stanbol.enhancer.engines.opennlp.impl;

import org.apache.clerezza.rdf.core.UriRef;

public class NameOccurrence {

    public final String name;
    
    public final UriRef type;
    
    public final Integer start;

    public final Integer end;

    public final String context;

    public final Double confidence;

    public NameOccurrence(String name, Integer start, Integer end, UriRef type,
            String context, Double confidence) {
        this.name = name;
        this.type = type;
        this.start = start;
        this.end = end;
        this.context = context;
        this.confidence = confidence;
    }

    @Override
    public String toString() {
        return String.format(
                "[name='%s', start='%d', end='%d', type='%s', confidence='%f', context='%s']",
                name, start, end, type, confidence, context);
    }

}

==> apache-stanbol-1.0.0-source-release.zip: apache-stanbol-1.0.0/enhancement-engines/opennlp/opennlp-ner/src/main/java/org/apache/stanbol/enhancer/engines/opennlp/impl/NameOccurrence.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.stanbol.enhancer.engines.opennlp.impl;

import org.apache.clerezza.commons.rdf.IRI;

public class NameOccurrence {

    public final String name;
    
    public final IRI type;
    
    public final Integer start;

    public final Integer end;

    public final String context;

    public final Double confidence;

    public NameOccurrence(String name, Integer start, Integer end, IRI type,
            String context, Double confidence) {
        this.name = name;
        this.type = type;
        this.start = start;
        this.end = end;
        this.context = context;
        this.confidence = confidence;
    }

    @Override
    public String toString() {
        return String.format(
                "[name='%s', start='%d', end='%d', type='%s', confidence='%f', context='%s']",
                name, start, end, type, confidence, context);
    }

}
